/* 
 * File:   main.h
 * Author: CYRAX
 *
 * Created on February 16, 2014, 11:42 AM
 */

#ifndef MAIN_H
#define	MAIN_H

#define	PIC_CLK 16000000 /* Clock Frequency in Hz */

// Function prototypes
extern void MAX3100_init(void);
extern void SendString(unsigned char *str);
extern void delay( char millisec );
extern void putst(register const char *str);
// Manual SPI control for MAX3100
// #define MAX3100_IRQ	    RB2 //Set As Input  (PIC PIN35 -> MAX3100 PIN5)/* IRQ */
#define MAX3100_CS          RB4 //Set As Output (PIC PIN37 -> MAX3100 PIN4)/* Chip Select */
#define MAX3100_SPI_CLK     RC3 //Set As Output (PIC PIN18 -> MAX3100 PIN3)/* SPI Clock */
#define MAX3100_SPI_IN	    RC4 //Set As Input  (PIC PIN23 -> MAX3100 PIN2)/* SPI Data In */
#define MAX3100_SPI_OUT     RC5 //Set as Output (PIC PIN24 -> MAX3100 PIN1)/* SPI Data Out */

/* Port A used for analog inputs (ex. LEDS) */
#define PORTA_INIT	0b00000000          /* PORTA init data */
#define	TRISA_INIT	0b00000000	    /* SETUP PORT A I/O*/

/* ==== ADCON0 REGISTER ====*/
#define	ADCON0_INIT	0b11000001	    /* A/D Control Register0 - controls the operation of the A/D module. RC osc, CH0 selected *//*
* View The PIC16F877 DataSheet Under "ADCON0 REGISTER"
==== bit 0 ADON: A/D On bit ====
1 = A/D converter module is operating
0 = A/D converter module is shut-off and consumes no operating current
=================================
==== bit 1 Unimplemented: Read as '0' ====
==========================================
==== bit 2 GO/DONE: A/D Conversion Status bit ====
 If ADON = 1:
1 = A/D conversion in progress (setting this bit starts the A/D conversion)
0 = A/D conversion not in progress (this bit is automatically cleared by hardware when the A/D
conversion is complete)
==========================================
==== bit 5-3 CHS2:CHS0: Analog Channel Select bits ===
000 = channel 0, (RA0/AN0)
001 = channel 1, (RA1/AN1)
010 = channel 2, (RA2/AN2)
011 = channel 3, (RA3/AN3)
100 = channel 4, (RA5/AN4)
101 = channel 5, (RE0/AN5)
110 = channel 6, (RE1/AN6)
111 = channel 7, (RE2/AN7)
==========================================
==== bit 7-6 ADCS1:ADCS0: A/D Conversion Clock Select bits ====
00 = FOSC/2
01 = FOSC/8
10 = FOSC/32
11 = FRC (clock derived from the internal A/D module RC oscillator)
*END OF ADCON0 REGISTER
===========================================
 */
/* ==== ADCON1 REGISTER ====*/
#define	ADCON1_INIT	0b10001110	    /* A/D Control Register1 - configures the functions of the port pinsright justified 1 AD ch, int. ref *//*
* View The PIC16F877 DataSheet Under "ADCON1 REGISTER"
==== bit 7 ADFM: A/D Result Format Select bit ====
1 = Right justified. 6 Most Significant bits of ADRESH are read as ?0?.
0 = Left justified. 6 Least Significant bits of ADRESL are read as ?0?.
==== bit 6-4 Unimplemented: Read as '0' ====
==== bit 3-0 PCFG3:PCFG0: A/D Port Configuration Control bits: ====
(bit) |AN7|AN6|AN5|AN4| AN3 |AN2|AN1|AN0|VREF+|VREF-|CHAN/REF
(0011)| D | D | D | A |VREF+| A | A | A | RA3 | VSS | 4/1
*A = Analog input D = Digital I/O
*END OF ADCON1 REGISTER
===========================================
*/
#define	TXLED_ON        RA1 /* Set As Output (PIC PIN3 -> LED */

/*	Port B signals
 * RB2 <-- Input
 * RB4 --> Output     */
#define PORTB_INIT	0b00000000	    /* PORTB init data */
#define TRISB_INIT	0b00000100          /* SETUP PORT A I/O*/

/*	Port C signals
 * RC3 --> Output
 * RC4 <-- Input
 * RC5 --> Output	*/

/* RC6 - RC7 are reserved for serial IO */

#define PORTC_INIT	0b00000000	/* PORTC init data */
#define TRISC_INIT	0b00010000


#endif	/* MAIN_H */

